import adonthell

# -- print inventories
def print_inventories (inventories):
    for inv in inventories:
        slot = inv.first ()
        num = 0
        while slot != None:
            num = num + 1
            if slot.count () == 0: print "Slot %i empty" % num
            else: print "Slot %i contains %i item(s): %s" % (num, slot.count (), slot.get_item ().name ())
            slot = inv.next ()
        print "-------------------"

# -- advance gametime by 'm' minutes
def pass_time (m):
    t_minutes = adonthell.gamedate_time () + m * 10
    
    while adonthell.gamedate_time () < t_minutes:
        adonthell.gametime_update ()
        adonthell.gamedate_update ()
    
    print ""
        
# -- print current gametime
def print_time ():
    hour = adonthell.gamedate_hour ()
    minute = adonthell.gamedate_minute ()
    
    print "\b\b\b\b\b\b",
    print "%02i:%02i" % (hour, minute)


# -- initialize event handler and gametime subsystems
adonthell.event_handler_init ()
adonthell.gametime_init (10)

# -- make a clock thingy that prints the time every minute
clock = adonthell.time_event ("1m")
clock.set_callback (print_time)
clock.set_repeat ("1m", -1)
clock.thisown = 0

events = adonthell.event_list ()
events.add_event (clock)

# -- create some mutable items:
print "creating mutable items ..."

Lamp = adonthell.item_base (1)
Lamp.load ("lamp.item")
Lamp.thisown = 0

Oil = adonthell.item_base (1)
Oil.load ("oil_flask.item")
Oil.thisown = 0

Oil2 = adonthell.item_base (1)
Oil2.load ("oil_flask.item")
Oil2.thisown = 0

Poison = adonthell.item_base (1)
Poison.load ("nightshade_syrup.item")
Poison.thisown = 0

# -- create immutable items:
print "creating immutable items ..."

Coin = adonthell.item_base (0)
Coin.load ("coin.item")
Coin.thisown = 0
adonthell.item_storage_add (Coin)

Stick = adonthell.item_base (0)
Stick.load ("stick.item")
Stick.thisown = 0
adonthell.item_storage_add (Stick)

Knife = adonthell.item_base (0)
Knife.load ("knife.item")
Knife.thisown = 0
adonthell.item_storage_add (Stick)

Arrow = adonthell.item_base (0)
Arrow.load ("arrow.item")
Arrow.thisown = 0
adonthell.item_storage_add (Arrow)

# -- create some inventories:
print "creating inventories ..."

A = adonthell.inventory (4, 1)
B = adonthell.inventory (4, 1)

# -- populate inventories
print "populating inventories ..."

A.add (Coin, 1154)
A.add (Lamp)
A.add (Oil)
A.add (Oil2)

B.add (Knife)
B.add (A.first ().get_item (), 1000)
B.add (Stick, 36)
print_inventories ([A, B])

# -- the different tests:
def test_recharge ():
    Oil = A.find ("Oil Flask", adonthell.inventory.MATCH_NAME)

    print "     Lamp charge / max: ", Lamp.charge (), "/", Lamp.max_charge ()
    print "Oil flask charge / max: ", Oil.charge (), "/", Oil.max_charge ()

    # turn on lamp
    Lamp.use (None)

    # pass some time
    pass_time (15)

    print "     Lamp charge / max: ", Lamp.charge (), "/", Lamp.max_charge ()
    print "Oil flask charge / max: ", Oil.charge (), "/", Oil.max_charge ()

    A.combine (Lamp.get_slot (), Oil.get_slot ())
    Oil = A.find ("Oil Flask", adonthell.inventory.MATCH_NAME)

    print_inventories ([A])
    print "     Lamp charge / max: ", Lamp.charge (), "/",Lamp.max_charge ()
    print "Oil flask charge / max: ", Oil.charge (), "/", Oil.max_charge ()

    pass_time (60)
    A.combine (Lamp.get_slot (), Oil.get_slot ())
    Oil = A.find ("Lampfuel", adonthell.inventory.MATCH_CATEGORY)

    print "     Lamp charge / max: ", Lamp.charge (), "/",Lamp.max_charge ()
    print "Oil flask charge / max: ", Oil.charge (), "/", Oil.max_charge ()

    Lamp.use (None)
    pass_time (65)
    print "     Lamp charge / max: ", Lamp.charge (), "/",Lamp.max_charge ()
    print "Oil flask charge / max: ", Oil.charge (), "/", Oil.max_charge ()

    A.combine (Lamp.get_slot (), Oil.get_slot ())
    Oil = A.find ("Oil Flask", adonthell.inventory.MATCH_NAME)

    print_inventories ([A])
    print "     Lamp charge / max: ", Lamp.charge (), "/",Lamp.max_charge ()
    print "Oil flask charge / max: ", Oil.charge (), "/", Oil.max_charge ()


def test_transform ():
    print ""
    print_inventories ([B])
    print "Combining Sticks with Knife ..."
    B.combine (B.find ("Stick", adonthell.inventory.MATCH_NAME).get_slot (), B.first ())
    print_inventories ([B])

    print "Adding some poison ..."
    A.add (Poison)
    print_inventories ([A])
    print "Poison charge / max: ", Poison.charge (), "/", Poison.max_charge ()
    
    print "Poisoning Arrows ..."
    B.combine (B.find ("Arrow", adonthell.inventory.MATCH_NAME).get_slot (), A.first ())
    print_inventories ([A, B])

    
# -- run tests
test_recharge ()
test_transform ()
